@@ -38,8 +38,8 @@ namespace Private
     {
         const auto post = !postId.isEmpty() ? (QLatin1String("/posts/") % postId) : QString();
         const auto comment = !commentId.isEmpty() ? (QLatin1Char('/') % commentId) : QString();
-        auto path = QLatin1String("blogger/v3/blogs/") % blogId 
-                        % post % QLatin1String("/comments") % comment;
+        const auto path = QLatin1String("blogger/v3/blogs/") % blogId
+                            % post % QLatin1String("/comments") % comment;
         return path;
     }
 
@@ -56,7 +56,8 @@ namespace Private
                       const QString &postId = QString()) -> QString
     {
         const auto post = !postId.isEmpty() ? (QLatin1Char('/') % postId) : QString();
-        const auto path = QLatin1String("blogger/v3/blogs/") % blogId % QLatin1String("/posts");
+        const auto path = QLatin1String("blogger/v3/blogs/") % blogId
+                            % QLatin1String("/posts") % post;
         return path;
     }
 
